@@ -93,7 +93,7 @@ namespace HGW {
     void collectReadsAndCoverage(Segs::ReadCollection &col, htsFile *bam, sam_hdr_t *hdr_ptr,
                                  hts_idx_t *index, int threads, Utils::Region *region,
                                  bool coverage, std::vector<Parse::Parser> &filters, BS::thread_pool &pool,
-                                 int parse_mods);
+                                 const int parse_mods, const bool add_soft_clip_space);
 
     void iterDrawParallel(Segs::ReadCollection &col, htsFile *b, sam_hdr_t *hdr_ptr, hts_idx_t *index, int threads,
                           Utils::Region *region, bool coverage, std::vector<Parse::Parser> &filters,
