@@ -118,8 +118,7 @@ namespace Commands {
             p->target_qname = "";
             for (auto &cl: p->collections) {
                 cl.vScroll = 0;
-                cl.skipDrawingCoverage = false;
-                cl.skipDrawingReads = false;
+                cl.resetDrawState();
             }
             for (auto &rgn: p->regions) {
                 rgn.sortOption = Utils::SortType::NONE, rgn.sortPos = -1;
@@ -314,8 +313,7 @@ namespace Commands {
             if (p->mode == Manager::Show::SINGLE) {
                 p->processed = true;
                 for (auto &cl : p->collections) {
-                    cl.skipDrawingReads = false;
-                    cl.skipDrawingCoverage = false;
+                    cl.resetDrawState();
                 }
             } else {
                 p->processed = false;
@@ -354,8 +352,7 @@ namespace Commands {
         p->opts.alignments = !p->opts.alignments;
         if (p->frameId >= 0) {
             for (auto &cl: p->collections) {
-                cl.skipDrawingCoverage = false;
-                cl.skipDrawingReads = false;
+                cl.resetDrawState();
             }
             p->redraw = true;
         }
@@ -369,8 +366,7 @@ namespace Commands {
         p->opts.data_labels = !p->opts.data_labels;
         if (p->frameId >= 0) {
             for (auto &cl: p->collections) {
-                cl.skipDrawingCoverage = false;
-                cl.skipDrawingReads = false;
+                cl.resetDrawState();
             }
             p->redraw = true;
         }
@@ -589,8 +585,8 @@ namespace Commands {
         }
         p->highlightQname();
         p->processed = true;
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
+//        p->imageCache.clear();
+//        p->imageCacheQueue.clear();
         return Err::NONE;
     }
 
@@ -685,8 +681,7 @@ namespace Commands {
             p->filters.clear();
         }
         for (auto &cl : p->collections) {
-            cl.skipDrawingReads = false;
-            cl.skipDrawingCoverage = false;
+            cl.resetDrawState();
         }
 
         p->imageCacheQueue.clear();
@@ -715,8 +710,7 @@ namespace Commands {
         p->opts.max_coverage = std::max(0, p->opts.max_coverage);
         if (p->frameId >= 0) {
             for (auto &cl: p->collections) {
-                cl.skipDrawingReads = false;
-                cl.skipDrawingCoverage = false;
+                cl.resetDrawState();
             }
             p->processed = false;
             p->imageCache.clear();
@@ -861,8 +855,7 @@ namespace Commands {
         if (p->frameId >= 0) {
             p->processed = false;
             for (auto &cl: p->collections) {
-                cl.skipDrawingCoverage = false;
-                cl.skipDrawingReads = false;
+                cl.resetDrawState();
             }
             p->imageCache.clear();
             p->imageCacheQueue.clear();
@@ -948,8 +941,7 @@ namespace Commands {
                 SkDynamicMemoryWStream buffer;
 
                 for (auto &cl: p->collections) {
-                    cl.skipDrawingCoverage = false;
-                    cl.skipDrawingReads = false;
+                    cl.resetDrawState();
                 }
                 if (format_str == "pdf") {
                     auto pdfDocument = SkPDF::MakeDocument(&buffer);
@@ -1092,7 +1084,7 @@ namespace Commands {
             bam1_t* a = bam_init1();
             if (sam_itr_next(file_ptrs[i], region_iters[i], a) >= 0) {
                 Segs::Align alignment = Segs::Align(a);
-                Segs::align_init(&alignment, 0);  // no need to parse mods/tags here
+                Segs::align_init(&alignment, 0, p->opts.soft_clip_threshold > 0);  // no need to parse mods/tags here
                 pq.push({std::move(alignment), file_ptrs[i], region_iters[i], i});
             } else {
                 bam_destroy1(a);
@@ -1126,7 +1118,7 @@ namespace Commands {
                 }
             }
             if (sam_itr_next(item.file_ptr, item.bam_iter, item.align.delegate) >= 0) {
-                Segs::align_init(&item.align, 0);
+                Segs::align_init(&item.align, 0, 1);
                 pq.push(item);
             } else {
                 bam_destroy1(item.align.delegate);
@@ -1225,11 +1217,11 @@ namespace Commands {
                     std::string g = p->opts.genome_tag;
                     p->opts.genome_tag = parts.back();
                     bool success = p->loadIdeogramTag();
+                    p->opts.genome_tag = g;
                     if (success) {
                         refreshGw(p);
                         return Err::NONE;
                     } else {
-                        p->opts.genome_tag = g;
                         return Err::INVALID_PATH;
                     }
                 }
@@ -1648,7 +1640,7 @@ namespace Commands {
         p->imageCacheQueue.clear();
         p->filters.clear();
         p->target_qname = "";
-        for (auto &cl: p->collections) { cl.vScroll = 0; cl.skipDrawingCoverage = false; cl.skipDrawingReads = false;}
+        for (auto &cl: p->collections) { cl.vScroll = 0; cl.resetDrawState(); }
         return Err::NONE;
     }
 
@@ -1755,8 +1747,7 @@ namespace Commands {
                     p->redraw = true;
                     p->processed = false;
                     for (auto &cl : p->collections) {
-                        cl.skipDrawingReads = false;
-                        cl.skipDrawingCoverage = false;
+                        cl.resetDrawState();
                     };
                 }
             }
