@@ -7,10 +7,8 @@
 #include <string>
 #include <cstdio>
 #include <vector>
-
 #include <glad.h>
 
-
 #include "htslib/faidx.h"
 #include "htslib/hts.h"
 #include "htslib/sam.h"
@@ -19,6 +17,13 @@
 #define SK_GL
 #include "include/core/SkCanvas.h"
 #include "include/core/SkSurface.h"
+#include "include/encode/SkPngEncoder.h"
+#include "include/encode/SkJpegEncoder.h"
+#include "include/encode/SkWebpEncoder.h"
+#include "include/docs/SkPDFDocument.h"
+#include "include/core/SkPictureRecorder.h"
+#include "include/core/SkPicture.h"
+#include "include/svg/SkSVGCanvas.h"
 
 #include "ankerl_unordered_dense.h"
 #include "drawing.h"
@@ -139,7 +144,7 @@ namespace Manager {
             pool.reset(opts.threads);
         }
         triggerClose = false;
-//        sortReadsBy = Manager::SortType::NONE;
+        window = nullptr;
 
     }
 
@@ -147,7 +152,7 @@ namespace Manager {
         if (window != nullptr) {
             glfwDestroyWindow(window);
         }
-        glfwTerminate();
+//        glfwTerminate();
         for (auto &bm: bams) {
             hts_close(bm);
         }
@@ -613,6 +618,7 @@ namespace Manager {
 
     void GwPlot::setVariantSite(std::string &chrom, long start, std::string &chrom2, long stop) {
         this->clearCollections();
+        this->regions.clear();
         long rlen = stop - start;
         bool isTrans = chrom != chrom2;
         if (!isTrans && rlen <= opts.split_view_size) {
@@ -943,7 +949,7 @@ namespace Manager {
 
             if (redraw) {
                 if (mode == Show::SINGLE) {
-                    drawScreen(sSurface->getCanvas(), sContext, sSurface);
+                    drawScreen();
                 } else if (mode == Show::TILED) {
                     drawTiles(sSurface->getCanvas(), sContext, sSurface);
                     printIndexInfo();
@@ -984,90 +990,95 @@ namespace Manager {
     }
 
     void GwPlot::clearCollections() {
-        regions.clear();
+//        regions.clear();
         for (auto &cl: collections) {
-            for (auto &a: cl.readQueue) {
-                bam_destroy1(a.delegate);
+            if (cl.ownsBamPtrs) {
+                for (auto &a: cl.readQueue) {
+                    bam_destroy1(a.delegate);
+                }
             }
         }
         collections.clear();
     }
 
     void GwPlot::processBam() {  // collect reads, calc coverage and find y positions on plot
+        if (processed) {
+            return;
+        }
         const int parse_mods_threshold = (opts.parse_mods) ? opts.mods_qual_threshold : 0;
-        if (!processed) {
-            int idx = 0;
+        int idx = 0;
+        for (auto &cl: collections) {
+            for (auto &aln: cl.readQueue) {
+                bam_destroy1(aln.delegate);
+            }
+            cl.readQueue.clear();
+            cl.covArr.clear();
+            cl.mmVector.clear();
+            cl.levelsStart.clear();
+            cl.levelsEnd.clear();
+            cl.linked.clear();
+            cl.resetDrawState();
+        }
+        if (collections.size() != bams.size() * regions.size()) {
+            collections.resize(bams.size() * regions.size());
+        }
 
-            for (auto &cl: collections) {
-                for (auto &aln: cl.readQueue) {
-                    bam_destroy1(aln.delegate);
+        for (int i = 0; i < (int) bams.size(); ++i) {
+            htsFile *b = bams[i];
+            sam_hdr_t *hdr_ptr = headers[i];
+            hts_idx_t *index = indexes[i];
+
+            for (int j = 0; j < (int) regions.size(); ++j) {
+                Utils::Region * reg = &regions[j];
+
+                collections[idx].bamIdx = i;
+                collections[idx].regionIdx = j;
+                collections[idx].region = &regions[j];
+                if (collections[idx].skipDrawingReads) {
+                    continue;
                 }
-                cl.readQueue.clear();
-                cl.covArr.clear();
-                cl.mmVector.clear();
-                cl.levelsStart.clear();
-                cl.levelsEnd.clear();
-                cl.linked.clear();
-                cl.skipDrawingReads = false;
-                cl.skipDrawingCoverage = false;
-            }
-            if (collections.size() != bams.size() * regions.size()) {
-                collections.resize(bams.size() * regions.size());
-            }
-
-            for (int i = 0; i < (int) bams.size(); ++i) {
-                htsFile *b = bams[i];
-                sam_hdr_t *hdr_ptr = headers[i];
-                hts_idx_t *index = indexes[i];
-
-                for (int j = 0; j < (int) regions.size(); ++j) {
-                    Utils::Region * reg = &regions[j];
-
-                    collections[idx].bamIdx = i;
-                    collections[idx].regionIdx = j;
-                    collections[idx].region = &regions[j];
-                    if (collections[idx].skipDrawingReads) {
-                        continue;
-                    }
-                    if (opts.max_coverage) {
-                        collections[idx].covArr.resize(reg->end - reg->start + 1, 0);
-
-                    }
-                    if (opts.snp_threshold > reg->end - reg->start) {
-                        collections[idx].mmVector.resize(reg->end - reg->start + 1);
-                        Segs::Mismatches empty_mm = {0, 0, 0, 0};
-                        std::fill(collections[idx].mmVector.begin(), collections[idx].mmVector.end(), empty_mm);
-                    } else if (!collections[idx].mmVector.empty()) {
-                        collections[idx].mmVector.clear();
-                    }
-
-                    if (reg->end - reg->start < opts.low_memory || opts.link_op != 0) {
-
-                        HGW::collectReadsAndCoverage(collections[idx], b, hdr_ptr, index, opts.threads, reg,
-                                                     (bool) opts.max_coverage, filters, pool, parse_mods_threshold);
-
-                        int sort_state = Segs::getSortCodes(collections[idx].readQueue, opts.threads, pool, reg);
-                        int maxY = Segs::findY(collections[idx], collections[idx].readQueue, opts.link_op, opts,
-                                               false, sort_state);
-                        samMaxY = maxY;
-                    } else {
-                        samMaxY = opts.ylim;
-                    }
-
-                    idx += 1;
+                if (opts.max_coverage) {
+                    collections[idx].covArr.resize(reg->end - reg->start + 1, 0);
                 }
-            }
-
-            if (bams.empty()) {
-                collections.resize(regions.size());
-                for (int j = 0; j < (int) regions.size(); ++j) {
-                    collections[idx].bamIdx = -1;
-                    collections[idx].regionIdx = j;
-                    collections[idx].region = &regions[j];
-                    idx += 1;
+                if (opts.snp_threshold > reg->end - reg->start) {
+                    collections[idx].makeEmptyMMArray();
+                } else if (!collections[idx].mmVector.empty()) {
+                    collections[idx].mmVector.clear();
                 }
+
+                if (reg->end - reg->start < opts.low_memory || opts.link_op != 0) {
+
+                    HGW::collectReadsAndCoverage(collections[idx], b, hdr_ptr, index, opts.threads, reg,
+                                                 (bool) opts.max_coverage, filters, pool, parse_mods_threshold,
+                                                 opts.soft_clip_threshold > 0);
+
+                    int sort_state = Segs::getSortCodes(collections[idx].readQueue, opts.threads, pool, reg);
+                    int maxY = Segs::findY(collections[idx], collections[idx].readQueue, opts.link_op, opts,
+                                           false, sort_state);
+                    samMaxY = maxY;
+                } else {
+                    samMaxY = opts.ylim;
+                }
+
+                idx += 1;
             }
         }
+
+        if (bams.empty()) {
+            collections.resize(regions.size());
+            for (int j = 0; j < (int) regions.size(); ++j) {
+                collections[idx].bamIdx = -1;
+                collections[idx].regionIdx = j;
+                collections[idx].region = &regions[j];
+                idx += 1;
+            }
+        }
+    }
+
+    void GwPlot::resetCollectionRegionPtrs() {
+        for (auto& cl: collections) {
+            cl.region = &regions[cl.regionIdx];
+        }
     }
 
     void GwPlot::setGlfwFrameBufferSize() {
@@ -1096,67 +1107,76 @@ namespace Manager {
     }
 
     // sets scaling of y-position for various elements
-    void GwPlot::setScaling() {  // todo only call this function when needed - fb size change, or when plot items are added or removed
+    void GwPlot::setScaling() {
 
-        refSpace = fonts.overlayHeight * 2;
         if (opts.scale_bar) {
-            refSpace += fonts.overlayHeight * 2;
+            refSpace = gap + fonts.overlayHeight + gap + fonts.overlayHeight + gap;
+        } else {
+            refSpace = gap + fonts.overlayHeight + gap;
         }
-        sliderSpace = std::fmax((float)(fb_height * 0.0175), 10*monitorScale) + (gap * 0.5);
-        auto fbh = (float) fb_height;
-        auto fbw = (float) fb_width;
-        auto nbams = (float)bams.size();
+        sliderSpace = gap * 4; // gap + (fonts.overlayHeight * 2) + gap;
+
+        // Calculate available space
+        float availableHeight = fb_height - refSpace - sliderSpace;
+        float availableWidth = (float)fb_width;
+
+        // Calculate track heights
+        float nbams = (float)bams.size();
+        float nTracks = (float)tracks.size();
         if (tracks.empty()) {
-            totalTabixY = 0; tabixY = 0;
+            totalTabixY = 0;
+            tabixY = 0;
         } else {
-            totalTabixY = (fbh - refSpace - sliderSpace) * (float)opts.tab_track_height;
-            tabixY = totalTabixY / (float)tracks.size();
+            totalTabixY = availableHeight * (float)opts.tab_track_height;
+            tabixY = totalTabixY / nTracks;
         }
-
+        availableHeight -= totalTabixY;
         if (nbams == 0 || opts.max_coverage == 0) {
-            covY = 0; totalCovY = 0; trackY = 0;
-        } else {
-            totalCovY = (fbh - refSpace - sliderSpace - totalTabixY - gap) * ((opts.alignments) ? (float)0.15 : 1);
+            covY = 0;
+            totalCovY = 0;
+            trackY = 0;
+        } else if (!opts.alignments) {  // Only coverage, no alignments
+            totalCovY = availableHeight;
             covY = totalCovY / nbams;
-        }
-
-        if (!opts.alignments) {
             yScaling = 0;
             trackY = 0;
             pH = 0;
-        } else if (nbams > 0 && samMaxY > 0) {
-            trackY = (fbh - totalCovY - totalTabixY - refSpace - sliderSpace - gap) / nbams;
-            yScaling = (trackY - gap) / (double)samMaxY;
+        } else {
+            // Both coverage and alignments
+            float covProportion = 0.15f;
+            totalCovY = availableHeight * covProportion;
+            covY = totalCovY / nbams;
 
-            // Ensure yScaling is an integer if possible
-            if (yScaling > 1) {
-                yScaling = std::ceil(yScaling);
-            }
+            // Remaining space goes to alignments
+            availableHeight -= totalCovY;
+            trackY = availableHeight / nbams;
 
-            if (opts.tlen_yscale) {
-                pH = trackY / (float) opts.ylim;
-                yScaling *= 0.95;
-            } else {
-                if (yScaling > 3*monitorScale) {
-                    pH = yScaling - monitorScale;
-                    //                     if (monitorScale > 1) {
-                    //                        pH = yScaling - monitorScale;
-                    //                    } else {
-                    //                        pH = yScaling - 2;
-                    //                    }
+            // Calculate scaling factors
+            if (samMaxY > 0) {
+                yScaling = trackY / (double)samMaxY;
+                // Ensure yScaling is an integer if possible
+                if (yScaling > 1) {
+                    yScaling = std::ceil(yScaling);
+                }
+                if (opts.tlen_yscale) {
+                    pH = trackY / (float)opts.ylim;
+                    yScaling *= 0.95;
                 } else {
-                    pH = yScaling;
+                    if (yScaling > 3 * monitorScale) {
+                        pH = yScaling - monitorScale;
+                    } else {
+                        pH = yScaling;
+                    }
+                }
+                // Scale to pixel boundary
+                if (pH > 8) {
+                    pH = (float)(int)pH;
+                } else if (opts.tlen_yscale) {
+                    pH = std::fmax(pH, 8);
                 }
             }
-
-            if (pH > 8) {  // scale to pixel boundary
-                pH = (float)(int)pH;
-            } else if (opts.tlen_yscale) {
-                pH = std::fmax(pH, 8);
-            }
         }
-
-        regionWidth = fbw / (float)regions.size();
+        regionWidth = availableWidth / (float)regions.size();
         bamHeight = covY + trackY;
 
         for (auto &cl: collections) {
@@ -1196,17 +1216,21 @@ namespace Manager {
         }
     }
 
-    void GwPlot::drawScreen(SkCanvas* canvas, GrDirectContext* sContext, SkSurface *sSurface) {
+    bool GwPlot::collectionsNeedRedrawing() {
+        for (auto &cl: collections) {
+            if (!cl.skipDrawingCoverage || !cl.skipDrawingReads) {  // keep read and coverage area
+                return true;
+            }
+        }
+        return false;
+    }
 
+    void GwPlot::drawScreen(bool force_buffered_reads) {
 //        std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
-
         SkCanvas *canvasR = rasterCanvas;
-
-        canvas->drawPaint(opts.theme.bgPaint);
         canvasR->drawPaint(opts.theme.bgPaint);
 
         frameId += 1;
-
         if (bams.empty() && !regions.empty()) {
             canvasR->drawPaint(opts.theme.bgPaint);
             setScaling();
@@ -1218,9 +1242,8 @@ namespace Manager {
             setScaling();
 
             SkRect clip;
-
             // Draw background image
-            if (!imageCacheQueue.empty() && collections.size() > 1) {
+            if (!imageCacheQueue.empty() && !collections.empty()) {
                 canvasR->drawImage(imageCacheQueue.back().second, 0, 0);
                 clip.setXYWH(0, 0, fb_width, refSpace);
                 canvasR->drawRect(clip, opts.theme.bgPaint);
@@ -1237,7 +1260,7 @@ namespace Manager {
                 canvasR->save();
                 // for now cl.skipDrawingCoverage and cl.skipDrawingReads are almost always the same
                 if ((!cl.skipDrawingCoverage && !cl.skipDrawingReads) || imageCacheQueue.empty()) {
-                    clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, trackY + covY - gap);
+                    clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, trackY + covY);
                     canvasR->clipRect(clip, false);
                 } else if (cl.skipDrawingCoverage) {
                     clip.setXYWH(cl.xOffset, cl.yOffset, cl.regionPixels, cl.yPixels);
@@ -1249,7 +1272,7 @@ namespace Manager {
                 canvasR->drawPaint(opts.theme.bgPaint);
 
                 if (!cl.skipDrawingReads && !bams.empty()) {
-                    if (cl.regionLen >= opts.low_memory) {
+                    if (cl.regionLen >= opts.low_memory && !force_buffered_reads) {
                         assert (opts.link_op == 0 && regions[cl.regionIdx].getSortOption() == SortType::NONE);
                         // low memory mode will be used
                         cl.clear();
@@ -1276,10 +1299,10 @@ namespace Manager {
         if (opts.max_coverage) {
             Drawing::drawCoverage(opts, collections, canvasR, fonts, covY, refSpace, gap, monitorScale, bam_paths);
         }
-        Drawing::drawRef(opts, regions, fb_width, canvasR, fonts, fonts.overlayHeight, (float)regions.size(), gap, monitorScale, opts.scale_bar);
+        Drawing::drawRef(opts, regions, fb_width, canvasR, fonts, refSpace, (float)regions.size(), gap, monitorScale, opts.scale_bar);
         Drawing::drawBorders(opts, fb_width, fb_height, canvasR, regions.size(), bams.size(), trackY, covY, (int)tracks.size(), totalTabixY, refSpace, gap, totalCovY);
         Drawing::drawTracks(opts, fb_width, fb_height, canvasR, totalTabixY, tabixY, tracks, regions, fonts, gap, monitorScale, sliderSpace);
-        Drawing::drawChromLocation(opts, fonts, regions, ideogram, canvasR, fai, fb_width, fb_height, monitorScale, gap, drawLocation);
+        Drawing::drawChromLocation(opts, fonts, regions, ideogram, canvasR, fb_width, fb_height, monitorScale, gap, drawLocation, sliderSpace);
 
         imageCacheQueue.emplace_back(frameId, rasterSurfacePtr[0]->makeImageSnapshot());
 
@@ -1287,10 +1310,8 @@ namespace Manager {
 //        std::cerr << " time " << (std::chrono::duration_cast<std::chrono::milliseconds >(std::chrono::high_resolution_clock::now() - initial).count()) << std::endl;
     }
 
-    void GwPlot::drawScreenNoBuffer(SkCanvas* canvas, GrDirectContext* sContext, SkSurface *sSurface) {
+    void GwPlot::drawScreenNoBuffer() {
         //        std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
-
-        canvas->drawPaint(opts.theme.bgPaint);
         frameId += 1;
         if (regions.empty()) {
             setScaling();
@@ -1298,55 +1319,56 @@ namespace Manager {
             runDrawNoBuffer();
         }
         imageCacheQueue.emplace_back(frameId, rasterSurfacePtr[0]->makeImageSnapshot());
-        canvas->drawImage(imageCacheQueue.back().second, 0, 0);
-        sContext->flush();
-        glfwSwapBuffers(window);
         redraw = false;
 //                std::cerr << " time " << (std::chrono::duration_cast<std::chrono::milliseconds >(std::chrono::high_resolution_clock::now() - initial).count()) << std::endl;
-
     }
 
     void GwPlot::drawCursorPosOnRefSlider(SkCanvas *canvas) {
-        // determine if cursor is over the ref slider
-        if (regions.empty() || xPos_fb <= 0 || yPos_fb <= 0 || regionSelection < 0) {
+        // determine if cursor is in the slider region
+        if (regions.empty() || xPos_fb <= 0 || yPos_fb <= 0 || yPos_fb < fb_height - sliderSpace + (gap*0.5) || regionSelection < 0) {
             return;
         }
-        const float yh = std::fmax((float) (fb_height * 0.0175), 10 * monitorScale);
-        if (yPos_fb < fb_height - (yh * 2)) {
+        float colWidth = (float) fb_width / (float) regions.size();
+        regionSelection = (int)(xPos_fb / colWidth);
+        Utils::Region &rgn = regions[regionSelection];
+        if (rgn.ideogramStart <= 0 || xPos_fb < rgn.ideogramStart || xPos_fb > rgn.ideogramEnd) {
             return;
         }
-        const float colWidth = (float) fb_width / (float) regions.size();
-        const float gap = 25 * monitorScale;
-        const float gap2 = 50 * monitorScale;
-        const float drawWidth = colWidth - gap2;
-        float xp = ((float)regionSelection * colWidth) + gap;
-        if (xPos_fb < xp || xPos_fb > xp + drawWidth) {
+        float drawWidth = rgn.ideogramEnd - rgn.ideogramStart;
+        if (drawWidth <= 0) {
             return;
         }
-        int pos = (int)(((xPos_fb - xp) / drawWidth) * (float)regions[regionSelection].chromLen);
-        std::string s = Term::intToStringCommas(pos);
-
-        float estimatedTextWidth = (float) s.size() * fonts.overlayWidth;
-        SkRect rect;
-        SkPaint rect_paint = opts.theme.bgPaint;
-        rect_paint.setAlpha(160);
-        float xbox = xPos_fb + monitorScale;
-        rect.setXYWH(xbox, fb_height - (yh *2) + (monitorScale), estimatedTextWidth, (yh*(float)1.33) - monitorScale - monitorScale);
-        canvas->drawRect(rect, rect_paint);
+        int pos = (int)(((xPos_fb - rgn.ideogramStart) / drawWidth) * (float)regions[regionSelection].chromLen);
+        std::string s = regions[regionSelection].chrom + ":" + Term::intToStringCommas(pos);
+        float text_width = fonts.measureTextWidth(s);
         sk_sp<SkTextBlob> blob = SkTextBlob::MakeFromString(s.c_str(), fonts.overlay);
         SkPath path;
-        path.moveTo(xPos_fb, fb_height - (yh * 2));
-        path.lineTo(xPos_fb, fb_height - (yh * (float)0.66));
+        path.moveTo(xPos_fb, fb_height - (gap * 2.5));
+        path.lineTo(xPos_fb, fb_height - (gap * 2.5) - fonts.overlayHeight);
         canvas->drawPath(path, opts.theme.lcBright);
-        canvas->drawTextBlob(blob, xbox + monitorScale, fb_height - yh, opts.theme.tcDel);
+        float xbox = xPos_fb;
+        if (xbox + text_width > rgn.ideogramEnd) {
+            xbox -= text_width + monitorScale + monitorScale + monitorScale;
+        } else {
+            xbox += monitorScale + monitorScale;
+        }
+        float font_y_pos = fb_height - (gap * 2.5) - fonts.overlayHeight;
+        SkRect rect;
+        rect.setXYWH(xbox - (monitorScale*3), font_y_pos - fonts.overlayHeight, text_width + (monitorScale *6), fonts.overlayHeight);
+        canvas->drawRoundRect(rect, 5*monitorScale, 5*monitorScale, opts.theme.bgPaint);
+        canvas->drawTextBlob(blob, xbox, font_y_pos, opts.theme.tcDel);
+    }
+
+    void GwPlot::syncImageCacheQueue() {
+        while (!imageCacheQueue.empty() && imageCacheQueue.front().first != frameId) {
+            imageCacheQueue.pop_front();
+        }
     }
 
     void GwPlot::drawOverlay(SkCanvas *canvas) {
 
         if (!imageCacheQueue.empty()) {
-            while (!imageCacheQueue.empty() && imageCacheQueue.front().first != frameId) {
-                imageCacheQueue.pop_front();
-            }
+            syncImageCacheQueue();
             if (imageCacheQueue.empty()) {
                 return;
             }
@@ -1363,10 +1385,6 @@ namespace Manager {
         // draw main settings menu
         if (mode == Show::SETTINGS) {
             if (!imageCacheQueue.empty()) {
-                while (imageCacheQueue.front().first != frameId) {
-                    imageCacheQueue.pop_front();
-                }
-                canvas->drawImage(imageCacheQueue.back().second, 0, 0);
                 SkPaint bg = opts.theme.bgPaint;
                 bg.setAlpha(220);
                 canvas->drawPaint(bg);
@@ -1591,13 +1609,15 @@ namespace Manager {
             cog_paint.setStyle(SkPaint::kStroke_Style);
             canvas->drawRoundRect(rect, 3.5 * monitorScale, 3.5 * monitorScale, cog_paint);
 
+        // Line at mouse position
         } else if (drawLine && mode != SETTINGS) {
             SkPath path;
-            path.moveTo(xposm, 0);
-            path.lineTo(xposm, fb_height);
+            path.moveTo(xposm, refSpace);
+            path.lineTo(xposm, fb_height - sliderSpace);
             canvas->drawPath(path, opts.theme.lcJoins);
         }
 
+        // Help messages
         bool current_view_is_images = (!variantTracks.empty() && variantTracks[variantFileSelection].type == HGW::TrackType::IMAGES);
         if (bams.empty() && !current_view_is_images && mode != SETTINGS && frameId < 10) {
             float trackBoundary = fb_height - totalTabixY - refSpace;
@@ -1693,7 +1713,7 @@ namespace Manager {
                                   }
                               }).wait();
 
-        if (currentVarTrack->type == HGW::TrackType::IMAGES) { //multiLabels.size() < endIdx) {
+        if (currentVarTrack->type == HGW::TrackType::IMAGES) {
             currentVarTrack->appendImageLabels(bStart, bLen);
         }
     }
@@ -1727,7 +1747,6 @@ namespace Manager {
             std::rotate(srtLabels.begin(), pivot, pivot + 1);
         }
 
-//        canvas->drawPaint(opts.theme.bgPaint);
         canvas->drawPaint(opts.theme.bgPaintTiled);
         SkSamplingOptions sampOpts = SkSamplingOptions();
         int i = bStart;
@@ -1749,7 +1768,6 @@ namespace Manager {
                     float newHeight = newWidth / ratio;
                     rect.setXYWH(b.xStart, b.yStart, newWidth, newHeight);
                 }
-//                canvas->drawRect(rect, opts.theme.bgPaint);
                 canvas->drawImageRect(imageCache[i], rect, sampOpts);
                 if (currentVarTrack->multiLabels.empty()) {
                     ++i; continue;
@@ -1767,11 +1785,10 @@ namespace Manager {
         redraw = false;
     }
 
-    void GwPlot::runDrawOnCanvas(SkCanvas *canvas) {
+    void GwPlot::runDrawOnCanvas(SkCanvas *canvas, bool force_buffered_reads) {
         fetchRefSeqs();
         processBam();
         setScaling();
-
         canvas->drawPaint(opts.theme.bgPaint);
         SkRect clip;
 
@@ -1782,7 +1799,7 @@ namespace Manager {
             canvas->save();
             // for now cl.skipDrawingCoverage and cl.skipDrawingReads are almost always the same
             if ((!cl.skipDrawingCoverage && !cl.skipDrawingReads) || imageCacheQueue.empty()) {
-                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, trackY + covY - gap);
+                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, trackY + covY);
                 canvas->clipRect(clip, false);
             } else if (cl.skipDrawingCoverage) {
                 clip.setXYWH(cl.xOffset, cl.yOffset, cl.regionPixels, cl.yPixels);
@@ -1795,7 +1812,7 @@ namespace Manager {
 
             if (!cl.skipDrawingReads && !bams.empty()) {
 
-                if (cl.regionLen >= opts.low_memory) {
+                if (cl.regionLen >= opts.low_memory && !force_buffered_reads) {
                     assert (opts.link_op == 0 && regions[cl.regionIdx].getSortOption() == SortType::NONE);
                     // low memory mode will be used
                     cl.clear();
@@ -1821,14 +1838,14 @@ namespace Manager {
         if (opts.max_coverage) {
             Drawing::drawCoverage(opts, collections, canvas, fonts, covY, refSpace, gap, monitorScale, bam_paths);
         }
-        Drawing::drawRef(opts, regions, fb_width, canvas, fonts, fonts.overlayHeight, (float)regions.size(), gap, monitorScale, opts.scale_bar);
+        Drawing::drawRef(opts, regions, fb_width, canvas, fonts, refSpace, (float)regions.size(), gap, monitorScale, opts.scale_bar);
         Drawing::drawBorders(opts, fb_width, fb_height, canvas, regions.size(), bams.size(), trackY, covY, (int)tracks.size(), totalTabixY, refSpace, gap, totalCovY);
         Drawing::drawTracks(opts, fb_width, fb_height, canvas, totalTabixY, tabixY, tracks, regions, fonts, gap, monitorScale, sliderSpace);
-        Drawing::drawChromLocation(opts, fonts, regions, ideogram, canvas, fai, fb_width, fb_height, monitorScale, gap, drawLocation);
+        Drawing::drawChromLocation(opts, fonts, regions, ideogram, canvas, fb_width, fb_height, monitorScale, gap, drawLocation, sliderSpace);
     }
 
-    void GwPlot::runDraw() {
-        runDrawOnCanvas(rasterCanvas);
+    void GwPlot::runDraw(bool force_buffered_reads) {
+        runDrawOnCanvas(rasterCanvas, force_buffered_reads);
     }
 
     void GwPlot::runDrawNoBufferOnCanvas(SkCanvas* canvas) {
@@ -1859,9 +1876,7 @@ namespace Manager {
                     col.covArr.resize(reg->end - reg->start + 1, 0);
                 }
                 if (opts.snp_threshold > reg->end - reg->start) {
-                    col.mmVector.resize(reg->end - reg->start + 1);
-                    Segs::Mismatches empty_mm = {0, 0, 0, 0};
-                    std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
+                    col.makeEmptyMMArray();
                 } else if (!col.mmVector.empty()) {
                     col.mmVector.clear();
                 }
@@ -1889,7 +1904,7 @@ namespace Manager {
 
             // for now cl.skipDrawingCoverage and cl.skipDrawingReads are almost always the same
             if ((!cl.skipDrawingCoverage && !cl.skipDrawingReads) || imageCacheQueue.empty()) {
-                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, cl.yPixels - gap);
+                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, cl.yPixels);
                 canvas->clipRect(clip, false);
             } else if (cl.skipDrawingCoverage) {
                 clip.setXYWH(cl.xOffset, cl.yOffset, cl.regionPixels, cl.yPixels);
@@ -1921,10 +1936,10 @@ namespace Manager {
             Drawing::drawCoverage(opts, collections, canvas, fonts, covY, refSpace, gap, monitorScale, bam_paths);
         }
 
-        Drawing::drawRef(opts, regions, fb_width, canvas, fonts, fonts.overlayHeight, (float)regions.size(), gap, monitorScale, opts.scale_bar);
+        Drawing::drawRef(opts, regions, fb_width, canvas, fonts, refSpace, (float)regions.size(), gap, monitorScale, opts.scale_bar);
         Drawing::drawBorders(opts, fb_width, fb_height, canvas, regions.size(), bams.size(), trackY, covY, (int)tracks.size(), totalTabixY, refSpace, gap, totalCovY);
         Drawing::drawTracks(opts, fb_width, fb_height, canvas, totalTabixY, tabixY, tracks, regions, fonts, gap, monitorScale, sliderSpace);
-        Drawing::drawChromLocation(opts, fonts, regions, ideogram, canvas, fai, fb_width, fb_height, monitorScale, gap, drawLocation);
+        Drawing::drawChromLocation(opts, fonts, regions, ideogram, canvas, fb_width, fb_height, monitorScale, gap, drawLocation, sliderSpace);
 //        std::cerr << " time runDrawNoBufferOnCanvas " << (std::chrono::duration_cast<std::chrono::milliseconds >(std::chrono::high_resolution_clock::now() - initial).count()) << std::endl;
     }
 
@@ -1933,10 +1948,42 @@ namespace Manager {
     }
 
 
+    void GwPlot::prepareSelectedRegion() {
+
+    }
+
+
+    std::string GwPlot::flushLog() {
+        std::string raw_output = outStr.str();
+        // Remove any lines containing carriage returns
+        std::stringstream processed;
+        std::string line;
+        std::istringstream lines(raw_output);
+        while (std::getline(lines, line)) {
+            if (line.find('\r') == std::string::npos) {
+                processed << line;
+                if (!lines.eof()) {
+                    processed << '\n';
+                }
+            }
+        }
+        outStr.str("");
+        outStr.clear();
+        return processed.str();
+    }
+
+    void addAlignmentToSelectedRegion() {
+
+    }
+
+
     sk_sp<SkImage> GwPlot::makeImage() {
         makeRasterSurface();
         runDraw();
         sk_sp<SkImage> img(rasterSurfacePtr[0]->makeImageSnapshot());
+        for (auto &cl: collections) {
+            cl.resetDrawState();
+        }
         return img;
     }
 
@@ -1957,6 +2004,106 @@ namespace Manager {
         fclose(fout);
     }
 
+    void GwPlot::saveToPdf(const char* path, bool force_buffered_reads) {
+        SkFILEWStream out(path);
+        SkDynamicMemoryWStream buffer;
+        // We need to redraw everything
+        redraw = true;
+        for (auto &cl: collections) {
+            cl.resetDrawState();
+        }
+        auto pdfDocument = SkPDF::MakeDocument(&buffer);
+        SkCanvas *canvas = pdfDocument->beginPage(opts.dimensions.x, opts.dimensions.y);
+        setImageSize(opts.dimensions.x, opts.dimensions.y);
+        if (opts.link_op == 0 && !force_buffered_reads) {
+            runDrawNoBufferOnCanvas(canvas);
+        } else {
+            runDrawOnCanvas(canvas, force_buffered_reads);
+        }
+        pdfDocument->close();
+        buffer.writeToStream(&out);
+        // Make sure later draw calls are not skipped
+        redraw = true;
+        for (auto &cl: collections) {
+            cl.resetDrawState();
+        }
+    }
+
+    void GwPlot::saveToSvg(const char* path, bool force_buffered_reads) {
+        SkFILEWStream out(path);
+        redraw = true;
+        for (auto &cl: collections) {
+            cl.resetDrawState();
+        }
+        setImageSize(opts.dimensions.x, opts.dimensions.y);
+        SkPictureRecorder recorder;
+        SkCanvas* canvas = recorder.beginRecording(SkRect::MakeWH(opts.dimensions.x, opts.dimensions.y));
+        if (opts.link_op == 0 && !force_buffered_reads) {
+            runDrawNoBufferOnCanvas(canvas);
+        } else {
+            runDrawOnCanvas(canvas, force_buffered_reads);
+        }
+        sk_sp<SkPicture> picture = recorder.finishRecordingAsPicture();
+        std::unique_ptr<SkCanvas> svgCanvas = SkSVGCanvas::Make(SkRect::MakeWH(opts.dimensions.x, opts.dimensions.y), &out);
+        if (svgCanvas) {
+            picture->playback(svgCanvas.get());
+        };
+        redraw = true;
+        for (auto &cl: collections) {
+            cl.resetDrawState();
+        }
+    }
+
+    std::pair<const uint8_t*, size_t> GwPlot::encodeToPng(int compression_level) {
+        assert (resterSurface != nullptr);
+        sk_sp<SkImage> img = rasterSurface->makeImageSnapshot();
+#ifndef OLD_SKIA
+        SkPngEncoder::Options options;
+        options.fZLibLevel = compression_level;
+        sk_sp<SkData> png(SkPngEncoder::Encode(nullptr, img.get(), options));
+#else
+        sk_sp<SkData> png(img->encodeToData());  // sk_sp is a shared pointer
+#endif
+        m_encodedPngData = png; // Store as a member variable of type sk_sp<SkData>
+        return {static_cast<const uint8_t*>(m_encodedPngData->data()), m_encodedPngData->size()};
+    }
+
+    std::pair<const uint8_t*, size_t> GwPlot::encodeToJpeg(int quality) {
+        assert(rasterSurface != nullptr);
+        sk_sp<SkImage> img = rasterSurface->makeImageSnapshot();
+        SkJpegEncoder::Options options;
+        options.fQuality = quality;
+#if defined(_WIN32)  // For Windows convert SkImage to SkPixmap
+        std::cerr << "Error: this function is not supported for Windows at the moment\n";
+        return {nullptr, 0};
+#else
+    #ifndef OLD_SKIA
+        m_encodedJpegData = SkJpegEncoder::Encode(nullptr, img.get(), options);
+        return {static_cast<const uint8_t*>(m_encodedJpegData->data()), m_encodedJpegData->size()};
+    #else
+        SkBitmap bitmap;
+        if (!bitmap.tryAllocPixels(SkImageInfo::MakeN32Premul(img->width(), img->height()))) {
+            std::cerr << "Error: failed to allocate bitmap for JPEG encoding\n";
+            return {nullptr, 0};
+        }
+        if (!img->readPixels(nullptr, bitmap.pixmap(), 0, 0)) {
+            std::cerr << "Error: failed to read pixels from image\n";
+            return {nullptr, 0};
+        }
+        // Create a memory stream to write JPEG data
+        SkDynamicMemoryWStream stream;
+        if (!SkJpegEncoder::Encode(&stream, bitmap.pixmap(), options)) {
+            std::cerr << "Error: JPEG encoding failed\n";
+            return {nullptr, 0};
+        }
+        // Copy encoded data to a data object that your code can manage
+        sk_sp<SkData> data = stream.detachAsData();
+        m_encodedJpegData = data;
+        return {static_cast<const uint8_t*>(data->data()), data->size()};
+    #endif
+#endif
+    }
+
     void imageToPng(sk_sp<SkImage> &img, std::filesystem::path &path) {
         if (!img) { return; }
 #ifndef OLD_SKIA
@@ -1967,10 +2114,10 @@ namespace Manager {
 #endif
         if (!png) { return; }
 #if defined(_WIN32)
-	const wchar_t* outp = path.c_str();
-	std::wstring pw(outp);
-	std::string outp_str(pw.begin(), pw.end());
-	SkFILEWStream out(outp_str.c_str());
+        const wchar_t* outp = path.c_str();
+        std::wstring pw(outp);
+        std::string outp_str(pw.begin(), pw.end());
+        SkFILEWStream out(outp_str.c_str());
 #else
         SkFILEWStream out(path.c_str());
 #endif
@@ -2015,5 +2162,34 @@ namespace Manager {
         fclose(fout);
     }
 
-}
 
+    void drawImageCommands(Manager::GwPlot &plot, SkCanvas *canvas, std::vector<std::string> &extra_commands) {
+
+        plot.setImageSize(plot.opts.dimensions.x, plot.opts.dimensions.y);
+        bool stream_reads = plot.opts.link_op == 0;
+        if (!extra_commands.empty()) {
+            plot.regionSelection = 0;
+            for (const auto& command: extra_commands) {
+                plot.inputText = command;
+                plot.commandProcessed();
+                if (plot.regions.front().sortOption != 0) {
+                    stream_reads = false;
+                }
+            }
+        }
+        if (stream_reads) {
+            plot.runDrawNoBufferOnCanvas(canvas);
+        } else {
+            plot.runDrawOnCanvas(canvas);
+        }
+    }
+
+    size_t GwPlot::sizeOfBams() {
+        return bams.size();
+    }
+
+    size_t GwPlot::sizeOfRegions() {
+        return regions.size();
+    }
+
+}
