@@ -25,6 +25,7 @@
 #include "termcolor.h"
 #include "term_out.h"
 #include "themes.h"
+#include "gw_version.h"
 
 
 namespace Term {
@@ -40,7 +41,7 @@ namespace Term {
         out << termcolor::green << "count            expression?     " << termcolor::reset << "Count reads. See filter for example expressions'\n";
         out << termcolor::green << "cov              value?          " << termcolor::reset << "Change max coverage value. Use 'cov' to toggle coverage\n";
         out << termcolor::green << "edges                            " << termcolor::reset << "Toggle edges\n";
-        out << termcolor::green << "expand-track                     " << termcolor::reset << "Toggle showing expanded tracks\n";
+        out << termcolor::green << "expand-tracks                    " << termcolor::reset << "Toggle showing expanded tracks\n";
         out << termcolor::green << "filter           expression      " << termcolor::reset << "Examples 'filter mapq > 0', 'filter ~flag & secondary'\n                                 'filter mapq >= 30 or seq-len > 100'\n";
         out << termcolor::green << "find, f          qname?          " << termcolor::reset << "To find other alignments from selected read use 'find'\n                                 Or use 'find [QNAME]' to find target read'\n";
         out << termcolor::green << "goto             loci/feature    " << termcolor::reset << "e.g. 'goto chr1:1-20000'. 'goto hTERT' \n";
@@ -87,7 +88,7 @@ namespace Term {
         out << "previous region view " << termcolor::bright_yellow; Term::printKeyFromValue(opts.previous_region_view, out); out << "\n" << termcolor::reset;
         out << "cycle link mode      " << termcolor::bright_yellow; Term::printKeyFromValue(opts.cycle_link_mode, out); out << "\n" << termcolor::reset;
         out << "find all alignments  " << termcolor::bright_yellow; Term::printKeyFromValue(opts.find_alignments, out); out << "\n" << termcolor::reset;
-        out << "repeat last command  " << termcolor::bright_yellow; out << "ENTER" << "\n" << termcolor::reset;
+        out << "repeat last command  " << termcolor::bright_yellow; out << "CTRL + "; Term::printKeyFromValue(opts.repeat_command, out); out << "\n" << termcolor::reset;
         out << "resize window        " << termcolor::bright_yellow; out << "SHIFT + ARROW_KEY" << "\n" << termcolor::reset;
         out << "switch viewing mode  " << termcolor::bright_yellow; out << "TAB" << "\n" << termcolor::reset;
 
@@ -973,37 +974,37 @@ namespace Term {
 							if (r_idx >= rlen) {
 								break;
 							}
-							char ref_base;
-							switch (refSeq[r_idx]) {
-								case 'A': ref_base = 1; break;
-								case 'C': ref_base = 2; break;
-								case 'G': ref_base = 4; break;
-								case 'T': ref_base = 8; break;
-								case 'N': ref_base = 15; break;
-								case 'a': ref_base = 1; break;
-								case 'c': ref_base = 2; break;
-								case 'g': ref_base = 4; break;
-								case 't': ref_base = 8; break;
-								default: ref_base = 15; break;
-							}
+//							char ref_base;
+//							switch (refSeq[r_idx]) {
+//								case 'A': ref_base = 1; break;
+//								case 'C': ref_base = 2; break;
+//								case 'G': ref_base = 4; break;
+//								case 'T': ref_base = 8; break;
+//								case 'N': ref_base = 15; break;
+//								case 'a': ref_base = 1; break;
+//								case 'c': ref_base = 2; break;
+//								case 'g': ref_base = 4; break;
+//								case 't': ref_base = 8; break;
+//								default: ref_base = 15; break;
+//							}
 							char bam_base = bam_seqi(ptr_seq, idx);
-							if (bam_base != ref_base) {
-								switch (bam_base) {
-									case 1: mA+=1; break;
-									case 2: mC+=1; break;
-									case 4: mG+=1; break;
-									case 8: mT+=1; break;
-									default: mN+=1; break;
-								}
-							} else {
-								switch (bam_base) {
-									case 1: A+=1; break;
-									case 2: C+=1; break;
-									case 4: G+=1; break;
-									case 8: T+=1; break;
-									default: N+=1; break;
-								}
-							}
+//							if (bam_base != ref_base) {
+                            switch (bam_base) {
+                                case 1: mA+=1; break;
+                                case 2: mC+=1; break;
+                                case 4: mG+=1; break;
+                                case 8: mT+=1; break;
+                                default: mN+=1; break;
+                            }
+//							} else {
+//								switch (bam_base) {
+//									case 1: A+=1; break;
+//									case 2: C+=1; break;
+//									case 4: G+=1; break;
+//									case 8: T+=1; break;
+//									default: N+=1; break;
+//								}
+//							}
 							idx += 1;
 							r_pos += 1;
 						}
@@ -1421,7 +1422,6 @@ namespace Term {
     }
 
 #if !defined(__EMSCRIPTEN__)
-    const char* CURRENT_VERSION = "v1.1.4";
 
     size_t WriteCallback(void* contents, size_t size, size_t nmemb, void* userp) {
         ((std::string*)userp)->append((char*)contents, size * nmemb);
@@ -1463,7 +1463,7 @@ namespace Term {
         std::string latestVersion = getLatestVersion();
         if (!latestVersion.empty()) {
             std::vector<std::string> partsLatest = Utils::split(latestVersion, '.');
-            std::vector<std::string> partsCurrent = Utils::split(CURRENT_VERSION, '.');
+            std::vector<std::string> partsCurrent = Utils::split(GW_VERSION, '.');
             if ( std::stoi(partsLatest[1]) > std::stoi(partsCurrent[1]) ||
                  std::stoi(partsLatest[2]) > std::stoi(partsCurrent[2]) ) {
                 std::cout << "\nA new update is available: https://github.com/kcleal/gw/releases/tag/" << latestVersion << std::endl;
